==> intel-graphics-compiler-1.0.4.tar.gz: intel-graphics-compiler-igc-1.0.4/visa/Metadata.h <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#ifndef _METADATA_H_
#define _METADATA_H_

namespace vISA
{

class MDLocation {
    int lineNo;
    char* srcFilename;

    MDLocation() : lineNo(-1), srcFilename(nullptr) {}
    MDLocation(int lineNo, char *srcFilename) :
        lineNo(lineNo), srcFilename(srcFilename) {}

    friend class IR_Builder;

public:
    ~MDLocation() = default;
    void* operator new(size_t sz, Mem_Manager& m) { return m.alloc(sz); }
    int getLineNo() { return lineNo; }
    void setLineNo(int line) { lineNo = line; }
    char* getSrcFilename() const { return srcFilename; }
    void setSrcFilename(char* filename) { srcFilename = filename; }
};

}

#endif

==> intel-graphics-compiler_1.0.2652.orig.tar.gz: intel-graphics-compiler-igc-1.0.2652/visa/Metadata.h <==
/*===================== begin_copyright_notice ==================================

Copyright (c) 2017 Intel Corporation

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


======================= end_copyright_notice ==================================*/

#ifndef _METADATA_H_
#define _METADATA_H_

namespace vISA
{

class MDLocation {
    int lineNo;
    const char* srcFilename;

    MDLocation() : lineNo(-1), srcFilename(nullptr) {}
    MDLocation(int lineNo, const char *srcFilename) :
        lineNo(lineNo), srcFilename(srcFilename) {}

    friend class IR_Builder;

public:
    ~MDLocation() = default;
    void* operator new(size_t sz, Mem_Manager& m) { return m.alloc(sz); }
    int getLineNo() { return lineNo; }
    void setLineNo(int line) { lineNo = line; }
    const char* getSrcFilename() const { return srcFilename; }
    void setSrcFilename(const char* filename) { srcFilename = filename; }
};

}

#endif
